==> maru-0.0.1-all.zip: org/maru/dog/converter/DateConverter.java <==
/*
 * Copyright 2011 maru project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maru.dog.converter;

import java.util.Date;

import org.maru.core.annotation.Identifier;
import org.maru.core.annotation.Value;
import org.maru.dog.util.DateUtil;

/**
 * Default date converter class.
 *
 *
 */
public final class DateConverter {

    /**
     * Convert string type of date to {@link Date} following declared pattern
     * passed by a parameter
     *
     * @param date
     *            converted date.
     * @param pattern
     *            converting pattern format.
     * @return converted date.
     */
    @ConverterIdentifier(StringToDate.class)
    public Date stringToDate(@Value String date,
            @Identifier("pattern") String pattern) {
        return DateUtil.s2dConvert(date, pattern);
    }

    /**
     * Convert {@link Date} instance to {@link String} following declared
     * pattern passed by a parameter.
     *
     * @param date
     *            converted date.
     * @param pattern
     *            converting pattern format.
     * @return converted date.
     */
    @ConverterIdentifier(DateToString.class)
    public String dateToString(@Value Date date,
            @Identifier("pattern") String pattern) {
        return DateUtil.d2sConvert(date, pattern);
    }
}

==> maru-0.6.16-all.zip: org/maru/dog/converter/DateConverter.java <==
/*
 * Copyright 2011 maru project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maru.dog.converter;

import java.util.Date;

import org.maru.common.annotation.Identifier;
import org.maru.common.annotation.Value;
import org.maru.dog.util.DateUtil;

/**
 * Default date converter class.
 *
 *
 */
public final class DateConverter {

    /**
     * Convert string type of date to {@link Date} following declared pattern
     * passed by a parameter
     *
     * @param date
     *            converted date.
     * @param pattern
     *            converting pattern format.
     * @return converted date.
     */
    @ConverterIdentifier(StringToDate.class)
    public Date stringToDate(@Value String date,
            @Identifier("pattern") String pattern) {
        return DateUtil.s2dConvert(date, pattern);
    }

    /**
     * Convert {@link Date} instance to {@link String} following declared
     * pattern passed by a parameter.
     *
     * @param date
     *            converted date.
     * @param pattern
     *            converting pattern format.
     * @return converted date.
     */
    @ConverterIdentifier(DateToString.class)
    public String dateToString(@Value Date date,
            @Identifier("pattern") String pattern) {
        return DateUtil.d2sConvert(date, pattern);
    }
}
